@@ -28,7 +28,7 @@
 #include "boxed.h"
 #include "arg.h"
 #include "object.h"
-#include <gjs/gjs.h>
+#include <gjs/gjs-module.h>
 #include <gjs/compat.h>
 #include "repo.h"
 #include "function.h"
