@@ -33,14 +33,11 @@
 #include "arg.h"
 #include "foreign.h"
 
-#include <gjs/mem.h>
 #include <gjs/compat.h>
 
 #include <util/log.h>
 #include <util/misc.h>
 
-#include <jsapi.h>
-
 #include <girepository.h>
 #include <string.h>
 
